#[non_exhaustive]pub enum RegisterTaskWithMaintenanceWindowError {
DoesNotExistException(DoesNotExistException),
FeatureNotAvailableException(FeatureNotAvailableException),
IdempotentParameterMismatch(IdempotentParameterMismatch),
InternalServerError(InternalServerError),
ResourceLimitExceededException(ResourceLimitExceededException),
Unhandled(Unhandled),
}Expand description
Error type for the RegisterTaskWithMaintenanceWindowError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
DoesNotExistException(DoesNotExistException)
Error returned when the ID specified for a resource, such as a maintenance window or patch baseline, doesn't exist.
For information about resource quotas in Amazon Web Services Systems Manager, see Systems Manager service quotas in the Amazon Web Services General Reference.
FeatureNotAvailableException(FeatureNotAvailableException)
You attempted to register a LAMBDA or STEP_FUNCTIONS task in a region where the corresponding service isn't available.
IdempotentParameterMismatch(IdempotentParameterMismatch)
Error returned when an idempotent operation is retried and the parameters don't match the original call to the API with the same idempotency token.
InternalServerError(InternalServerError)
An error occurred on the server side.
ResourceLimitExceededException(ResourceLimitExceededException)
Error returned when the caller has exceeded the default resource quotas. For example, too many maintenance windows or patch baselines have been created.
For information about resource quotas in Systems Manager, see Systems Manager service quotas in the Amazon Web Services General Reference.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl RegisterTaskWithMaintenanceWindowError
impl RegisterTaskWithMaintenanceWindowError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the RegisterTaskWithMaintenanceWindowError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the RegisterTaskWithMaintenanceWindowError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_does_not_exist_exception(&self) -> bool
pub fn is_does_not_exist_exception(&self) -> bool
Returns true if the error kind is RegisterTaskWithMaintenanceWindowError::DoesNotExistException.
Sourcepub fn is_feature_not_available_exception(&self) -> bool
pub fn is_feature_not_available_exception(&self) -> bool
Returns true if the error kind is RegisterTaskWithMaintenanceWindowError::FeatureNotAvailableException.
Sourcepub fn is_idempotent_parameter_mismatch(&self) -> bool
pub fn is_idempotent_parameter_mismatch(&self) -> bool
Returns true if the error kind is RegisterTaskWithMaintenanceWindowError::IdempotentParameterMismatch.
Sourcepub fn is_internal_server_error(&self) -> bool
pub fn is_internal_server_error(&self) -> bool
Returns true if the error kind is RegisterTaskWithMaintenanceWindowError::InternalServerError.
Sourcepub fn is_resource_limit_exceeded_exception(&self) -> bool
pub fn is_resource_limit_exceeded_exception(&self) -> bool
Returns true if the error kind is RegisterTaskWithMaintenanceWindowError::ResourceLimitExceededException.