#[non_exhaustive]pub struct ValidationFinding {
pub type: Option<ValidationFindingType>,
pub code: Option<ValidationFindingCode>,
pub message: Option<String>,
pub provider_message: Option<String>,
pub scope: Option<ValidationFindingScope>,
}Expand description
A validation finding from a cloud connector validation check.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.type: Option<ValidationFindingType>The type of the validation finding.
code: Option<ValidationFindingCode>A code that identifies the specific validation finding.
message: Option<String>A message that describes the validation finding.
provider_message: Option<String>A message from the third-party cloud provider related to the validation finding.
scope: Option<ValidationFindingScope>The scope of the validation finding, identifying the specific resource affected.
Implementations
Sourceimpl ValidationFinding
impl ValidationFinding
Sourcepub fn type(&self) -> Option<&ValidationFindingType>
pub fn type(&self) -> Option<&ValidationFindingType>
The type of the validation finding.
Sourcepub fn code(&self) -> Option<&ValidationFindingCode>
pub fn code(&self) -> Option<&ValidationFindingCode>
A code that identifies the specific validation finding.
Sourcepub fn provider_message(&self) -> Option<&str>
pub fn provider_message(&self) -> Option<&str>
A message from the third-party cloud provider related to the validation finding.
Sourcepub fn scope(&self) -> Option<&ValidationFindingScope>
pub fn scope(&self) -> Option<&ValidationFindingScope>
The scope of the validation finding, identifying the specific resource affected.
Sourceimpl ValidationFinding
impl ValidationFinding
Sourcepub fn builder() -> ValidationFindingBuilder
pub fn builder() -> ValidationFindingBuilder
Creates a new builder-style object to manufacture ValidationFinding.