#[non_exhaustive]pub struct RegisterTaskWithMaintenanceWindowInput {Show 16 fields
pub window_id: Option<String>,
pub targets: Option<Vec<Target>>,
pub task_arn: Option<String>,
pub service_role_arn: Option<String>,
pub task_type: Option<MaintenanceWindowTaskType>,
pub task_parameters: Option<HashMap<String, MaintenanceWindowTaskParameterValueExpression>>,
pub task_invocation_parameters: Option<MaintenanceWindowTaskInvocationParameters>,
pub priority: Option<i32>,
pub max_concurrency: Option<String>,
pub max_errors: Option<String>,
pub logging_info: Option<LoggingInfo>,
pub name: Option<String>,
pub description: Option<String>,
pub client_token: Option<String>,
pub cutoff_behavior: Option<MaintenanceWindowTaskCutoffBehavior>,
pub alarm_configuration: Option<AlarmConfiguration>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.window_id: Option<String>The ID of the maintenance window the task should be added to.
targets: Option<Vec<Target>>The targets (either managed nodes or maintenance window targets).
One or more targets must be specified for maintenance window Run Command-type tasks. Depending on the task, targets are optional for other maintenance window task types (Automation, Lambda, and Step Functions). For more information about running tasks that don't specify targets, see Registering maintenance window tasks without targets in the Amazon Web Services Systems Manager User Guide.
Specify managed nodes using the following format:
Key=InstanceIds,Values=
Specify maintenance window targets using the following format:
Key=WindowTargetIds,Values=
task_arn: Option<String>The ARN of the task to run.
service_role_arn: Option<String>The Amazon Resource Name (ARN) of the IAM service role for Amazon Web Services Systems Manager to assume when running a maintenance window task. If you do not specify a service role ARN, Systems Manager uses a service-linked role in your account. If no appropriate service-linked role for Systems Manager exists in your account, it is created when you run RegisterTaskWithMaintenanceWindow.
However, for an improved security posture, we strongly recommend creating a custom policy and custom service role for running your maintenance window tasks. The policy can be crafted to provide only the permissions needed for your particular maintenance window tasks. For more information, see Setting up Maintenance Windows in the in the Amazon Web Services Systems Manager User Guide.
task_type: Option<MaintenanceWindowTaskType>The type of task being registered.
task_parameters: Option<HashMap<String, MaintenanceWindowTaskParameterValueExpression>>The parameters that should be passed to the task when it is run.
TaskParameters has been deprecated. To specify parameters to pass to a task when it runs, instead use the Parameters option in the TaskInvocationParameters structure. For information about how Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.
task_invocation_parameters: Option<MaintenanceWindowTaskInvocationParameters>The parameters that the task should use during execution. Populate only the fields that match the task type. All other fields should be empty.
priority: Option<i32>The priority of the task in the maintenance window, the lower the number the higher the priority. Tasks in a maintenance window are scheduled in priority order with tasks that have the same priority scheduled in parallel.
max_concurrency: Option<String>The maximum number of targets this task can be run for, in parallel.
Although this element is listed as "Required: No", a value can be omitted only when you are registering or updating a targetless task You must provide a value in all other cases.
For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1. This value doesn't affect the running of your task.
max_errors: Option<String>The maximum number of errors allowed before this task stops being scheduled.
Although this element is listed as "Required: No", a value can be omitted only when you are registering or updating a targetless task You must provide a value in all other cases.
For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1. This value doesn't affect the running of your task.
logging_info: Option<LoggingInfo>A structure containing information about an Amazon Simple Storage Service (Amazon S3) bucket to write managed node-level logs to.
LoggingInfo has been deprecated. To specify an Amazon Simple Storage Service (Amazon S3) bucket to contain logs, instead use the OutputS3BucketName and OutputS3KeyPrefix options in the TaskInvocationParameters structure. For information about how Amazon Web Services Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.
name: Option<String>An optional name for the task.
description: Option<String>An optional description for the task.
client_token: Option<String>User-provided idempotency token.
cutoff_behavior: Option<MaintenanceWindowTaskCutoffBehavior>Indicates whether tasks should continue to run after the cutoff time specified in the maintenance windows is reached.
-
CONTINUE_TASK: When the cutoff time is reached, any tasks that are running continue. The default value. -
CANCEL_TASK:-
For Automation, Lambda, Step Functions tasks: When the cutoff time is reached, any task invocations that are already running continue, but no new task invocations are started.
-
For Run Command tasks: When the cutoff time is reached, the system sends a
CancelCommandoperation that attempts to cancel the command associated with the task. However, there is no guarantee that the command will be terminated and the underlying process stopped.
The status for tasks that are not completed is
TIMED_OUT. -
alarm_configuration: Option<AlarmConfiguration>The CloudWatch alarm you want to apply to your maintenance window task.
Implementations
Sourceimpl RegisterTaskWithMaintenanceWindowInput
impl RegisterTaskWithMaintenanceWindowInput
Sourcepub fn window_id(&self) -> Option<&str>
pub fn window_id(&self) -> Option<&str>
The ID of the maintenance window the task should be added to.
Sourcepub fn targets(&self) -> &[Target]
pub fn targets(&self) -> &[Target]
The targets (either managed nodes or maintenance window targets).
One or more targets must be specified for maintenance window Run Command-type tasks. Depending on the task, targets are optional for other maintenance window task types (Automation, Lambda, and Step Functions). For more information about running tasks that don't specify targets, see Registering maintenance window tasks without targets in the Amazon Web Services Systems Manager User Guide.
Specify managed nodes using the following format:
Key=InstanceIds,Values=
Specify maintenance window targets using the following format:
Key=WindowTargetIds,Values=
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .targets.is_none().
Sourcepub fn service_role_arn(&self) -> Option<&str>
pub fn service_role_arn(&self) -> Option<&str>
The Amazon Resource Name (ARN) of the IAM service role for Amazon Web Services Systems Manager to assume when running a maintenance window task. If you do not specify a service role ARN, Systems Manager uses a service-linked role in your account. If no appropriate service-linked role for Systems Manager exists in your account, it is created when you run RegisterTaskWithMaintenanceWindow.
However, for an improved security posture, we strongly recommend creating a custom policy and custom service role for running your maintenance window tasks. The policy can be crafted to provide only the permissions needed for your particular maintenance window tasks. For more information, see Setting up Maintenance Windows in the in the Amazon Web Services Systems Manager User Guide.
Sourcepub fn task_type(&self) -> Option<&MaintenanceWindowTaskType>
pub fn task_type(&self) -> Option<&MaintenanceWindowTaskType>
The type of task being registered.
Sourcepub fn task_parameters(
&self,
) -> Option<&HashMap<String, MaintenanceWindowTaskParameterValueExpression>>
pub fn task_parameters( &self, ) -> Option<&HashMap<String, MaintenanceWindowTaskParameterValueExpression>>
The parameters that should be passed to the task when it is run.
TaskParameters has been deprecated. To specify parameters to pass to a task when it runs, instead use the Parameters option in the TaskInvocationParameters structure. For information about how Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.
Sourcepub fn task_invocation_parameters(
&self,
) -> Option<&MaintenanceWindowTaskInvocationParameters>
pub fn task_invocation_parameters( &self, ) -> Option<&MaintenanceWindowTaskInvocationParameters>
The parameters that the task should use during execution. Populate only the fields that match the task type. All other fields should be empty.
Sourcepub fn priority(&self) -> Option<i32>
pub fn priority(&self) -> Option<i32>
The priority of the task in the maintenance window, the lower the number the higher the priority. Tasks in a maintenance window are scheduled in priority order with tasks that have the same priority scheduled in parallel.
Sourcepub fn max_concurrency(&self) -> Option<&str>
pub fn max_concurrency(&self) -> Option<&str>
The maximum number of targets this task can be run for, in parallel.
Although this element is listed as "Required: No", a value can be omitted only when you are registering or updating a targetless task You must provide a value in all other cases.
For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1. This value doesn't affect the running of your task.
Sourcepub fn max_errors(&self) -> Option<&str>
pub fn max_errors(&self) -> Option<&str>
The maximum number of errors allowed before this task stops being scheduled.
Although this element is listed as "Required: No", a value can be omitted only when you are registering or updating a targetless task You must provide a value in all other cases.
For maintenance window tasks without a target specified, you can't supply a value for this option. Instead, the system inserts a placeholder value of 1. This value doesn't affect the running of your task.
Sourcepub fn logging_info(&self) -> Option<&LoggingInfo>
pub fn logging_info(&self) -> Option<&LoggingInfo>
A structure containing information about an Amazon Simple Storage Service (Amazon S3) bucket to write managed node-level logs to.
LoggingInfo has been deprecated. To specify an Amazon Simple Storage Service (Amazon S3) bucket to contain logs, instead use the OutputS3BucketName and OutputS3KeyPrefix options in the TaskInvocationParameters structure. For information about how Amazon Web Services Systems Manager handles these options for the supported maintenance window task types, see MaintenanceWindowTaskInvocationParameters.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
An optional description for the task.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
User-provided idempotency token.
Sourcepub fn cutoff_behavior(&self) -> Option<&MaintenanceWindowTaskCutoffBehavior>
pub fn cutoff_behavior(&self) -> Option<&MaintenanceWindowTaskCutoffBehavior>
Indicates whether tasks should continue to run after the cutoff time specified in the maintenance windows is reached.
-
CONTINUE_TASK: When the cutoff time is reached, any tasks that are running continue. The default value. -
CANCEL_TASK:-
For Automation, Lambda, Step Functions tasks: When the cutoff time is reached, any task invocations that are already running continue, but no new task invocations are started.
-
For Run Command tasks: When the cutoff time is reached, the system sends a
CancelCommandoperation that attempts to cancel the command associated with the task. However, there is no guarantee that the command will be terminated and the underlying process stopped.
The status for tasks that are not completed is
TIMED_OUT. -
Sourcepub fn alarm_configuration(&self) -> Option<&AlarmConfiguration>
pub fn alarm_configuration(&self) -> Option<&AlarmConfiguration>
The CloudWatch alarm you want to apply to your maintenance window task.
Sourceimpl RegisterTaskWithMaintenanceWindowInput
impl RegisterTaskWithMaintenanceWindowInput
Sourcepub fn builder() -> RegisterTaskWithMaintenanceWindowInputBuilder
pub fn builder() -> RegisterTaskWithMaintenanceWindowInputBuilder
Creates a new builder-style object to manufacture RegisterTaskWithMaintenanceWindowInput.